@@ -5,6 +5,9 @@
 extern int wharfShape;			/* =0 for non wharf placement */
 					/* =1 if in afterstep wharf */
 
+extern char szHangupCmd [2048];
+extern char szDailCmd [2048];
+
 typedef struct _XpmIcon
 {
         Pixmap pixmap;
